function [] = sensore(x,y,id,sens_att)
%accende e spegne i sensori usati
% x = coordinata x centrale
% y = coordinata y centrale
% id = id del sensore
% sens_att = vettore 1x3 con temp. umid. e irrag.
% se elemento =0 se non attivo, =1 se attivo

i = ['w','w','w'];

if sens_att(1)==1
    i(1)='r';
end

if sens_att(2)==1
    i(2)='b';
end

if sens_att(3)==1
    i(3)='y';
end


%sensore temperatura
t = patch([x-15, x-5, x-5, x-15], [y-7, y-7, y+7, y+7], i(1));
set(t, 'EdgeColor', 'r');

%sensore irraggiamento
ir = patch([x+5, x+15, x+15, x+5], [y-7, y-7, y+7, y+7], i(3));
set(ir, 'EdgeColor', 'y');

%sensore umidita
h = patch([x-5, x+5, x+5, x-5], [y-7, y-7, y+7, y+7], i(2));
set(h, 'EdgeColor', 'b');


% mTextBox = uicontrol('style','text');
% set(mTextBox,'String',num2str(id),'Position',[(x-15),(y-7),30,14]);

text('Position',[x+20 y],'string',num2str(id),'BackgroundColor','w');












